# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ProductSku(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sku_number': 'str',
        'price': 'float',
        'rrp': 'float',
        'group_buying_price': 'float',
        'images': 'Images',
        'barcode': 'str',
        'color': 'str',
        'size': 'str',
        'quantity': 'int',
        'is_onsale': 'bool',
        'net_weight': 'float',
        'gross_weight': 'float',
        'shipping_cost': 'float',
        'shipping_time': 'int',
        'model': 'str',
        'spec': 'str',
        'customs_unit_code': 'str',
        'customs_unit_code_package': 'str',
        'customs_unit_code_weight': 'str'
    }

    attribute_map = {
        'sku_number': 'skuNumber',
        'price': 'price',
        'rrp': 'rrp',
        'group_buying_price': 'groupBuyingPrice',
        'images': 'images',
        'barcode': 'barcode',
        'color': 'color',
        'size': 'size',
        'quantity': 'quantity',
        'is_onsale': 'isOnsale',
        'net_weight': 'netWeight',
        'gross_weight': 'grossWeight',
        'shipping_cost': 'shippingCost',
        'shipping_time': 'shippingTime',
        'model': 'model',
        'spec': 'spec',
        'customs_unit_code': 'customsUnitCode',
        'customs_unit_code_package': 'customsUnitCodePackage',
        'customs_unit_code_weight': 'customsUnitCodeWeight'
    }

    def __init__(self, sku_number=None, price=None, rrp=None, group_buying_price=None, images=None, barcode=None, color=None, size=None, quantity=None, is_onsale=None, net_weight=None, gross_weight=None, shipping_cost=None, shipping_time=None, model=None, spec=None, customs_unit_code=None, customs_unit_code_package=None, customs_unit_code_weight='035'):  # noqa: E501
        """ProductSku - a model defined in OpenAPI"""  # noqa: E501

        self._sku_number = None
        self._price = None
        self._rrp = None
        self._group_buying_price = None
        self._images = None
        self._barcode = None
        self._color = None
        self._size = None
        self._quantity = None
        self._is_onsale = None
        self._net_weight = None
        self._gross_weight = None
        self._shipping_cost = None
        self._shipping_time = None
        self._model = None
        self._spec = None
        self._customs_unit_code = None
        self._customs_unit_code_package = None
        self._customs_unit_code_weight = None
        self.discriminator = None

        if sku_number is not None:
            self.sku_number = sku_number
        if price is not None:
            self.price = price
        if rrp is not None:
            self.rrp = rrp
        if group_buying_price is not None:
            self.group_buying_price = group_buying_price
        if images is not None:
            self.images = images
        if barcode is not None:
            self.barcode = barcode
        if color is not None:
            self.color = color
        if size is not None:
            self.size = size
        if quantity is not None:
            self.quantity = quantity
        if is_onsale is not None:
            self.is_onsale = is_onsale
        if net_weight is not None:
            self.net_weight = net_weight
        if gross_weight is not None:
            self.gross_weight = gross_weight
        if shipping_cost is not None:
            self.shipping_cost = shipping_cost
        if shipping_time is not None:
            self.shipping_time = shipping_time
        if model is not None:
            self.model = model
        if spec is not None:
            self.spec = spec
        if customs_unit_code is not None:
            self.customs_unit_code = customs_unit_code
        if customs_unit_code_package is not None:
            self.customs_unit_code_package = customs_unit_code_package
        if customs_unit_code_weight is not None:
            self.customs_unit_code_weight = customs_unit_code_weight

    @property
    def sku_number(self):
        """Gets the sku_number of this ProductSku.  # noqa: E501


        :return: The sku_number of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._sku_number

    @sku_number.setter
    def sku_number(self, sku_number):
        """Sets the sku_number of this ProductSku.


        :param sku_number: The sku_number of this ProductSku.  # noqa: E501
        :type: str
        """

        self._sku_number = sku_number

    @property
    def price(self):
        """Gets the price of this ProductSku.  # noqa: E501

        The selling price of current SKU.  # noqa: E501

        :return: The price of this ProductSku.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this ProductSku.

        The selling price of current SKU.  # noqa: E501

        :param price: The price of this ProductSku.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def rrp(self):
        """Gets the rrp of this ProductSku.  # noqa: E501

        recommended retail price  # noqa: E501

        :return: The rrp of this ProductSku.  # noqa: E501
        :rtype: float
        """
        return self._rrp

    @rrp.setter
    def rrp(self, rrp):
        """Sets the rrp of this ProductSku.

        recommended retail price  # noqa: E501

        :param rrp: The rrp of this ProductSku.  # noqa: E501
        :type: float
        """

        self._rrp = rrp

    @property
    def group_buying_price(self):
        """Gets the group_buying_price of this ProductSku.  # noqa: E501

        group buying price  # noqa: E501

        :return: The group_buying_price of this ProductSku.  # noqa: E501
        :rtype: float
        """
        return self._group_buying_price

    @group_buying_price.setter
    def group_buying_price(self, group_buying_price):
        """Sets the group_buying_price of this ProductSku.

        group buying price  # noqa: E501

        :param group_buying_price: The group_buying_price of this ProductSku.  # noqa: E501
        :type: float
        """

        self._group_buying_price = group_buying_price

    @property
    def images(self):
        """Gets the images of this ProductSku.  # noqa: E501


        :return: The images of this ProductSku.  # noqa: E501
        :rtype: Images
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this ProductSku.


        :param images: The images of this ProductSku.  # noqa: E501
        :type: Images
        """

        self._images = images

    @property
    def barcode(self):
        """Gets the barcode of this ProductSku.  # noqa: E501


        :return: The barcode of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._barcode

    @barcode.setter
    def barcode(self, barcode):
        """Sets the barcode of this ProductSku.


        :param barcode: The barcode of this ProductSku.  # noqa: E501
        :type: str
        """

        self._barcode = barcode

    @property
    def color(self):
        """Gets the color of this ProductSku.  # noqa: E501


        :return: The color of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this ProductSku.


        :param color: The color of this ProductSku.  # noqa: E501
        :type: str
        """

        self._color = color

    @property
    def size(self):
        """Gets the size of this ProductSku.  # noqa: E501


        :return: The size of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ProductSku.


        :param size: The size of this ProductSku.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def quantity(self):
        """Gets the quantity of this ProductSku.  # noqa: E501

        The stock level of current SKU in current product.  # noqa: E501

        :return: The quantity of this ProductSku.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ProductSku.

        The stock level of current SKU in current product.  # noqa: E501

        :param quantity: The quantity of this ProductSku.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def is_onsale(self):
        """Gets the is_onsale of this ProductSku.  # noqa: E501


        :return: The is_onsale of this ProductSku.  # noqa: E501
        :rtype: bool
        """
        return self._is_onsale

    @is_onsale.setter
    def is_onsale(self, is_onsale):
        """Sets the is_onsale of this ProductSku.


        :param is_onsale: The is_onsale of this ProductSku.  # noqa: E501
        :type: bool
        """

        self._is_onsale = is_onsale

    @property
    def net_weight(self):
        """Gets the net_weight of this ProductSku.  # noqa: E501

        The default net weight of current SKU. If not present, then switch back to the default value of product  # noqa: E501

        :return: The net_weight of this ProductSku.  # noqa: E501
        :rtype: float
        """
        return self._net_weight

    @net_weight.setter
    def net_weight(self, net_weight):
        """Sets the net_weight of this ProductSku.

        The default net weight of current SKU. If not present, then switch back to the default value of product  # noqa: E501

        :param net_weight: The net_weight of this ProductSku.  # noqa: E501
        :type: float
        """

        self._net_weight = net_weight

    @property
    def gross_weight(self):
        """Gets the gross_weight of this ProductSku.  # noqa: E501

        The default gross weight of current SKU. If not present, then switch back to the default value of product  # noqa: E501

        :return: The gross_weight of this ProductSku.  # noqa: E501
        :rtype: float
        """
        return self._gross_weight

    @gross_weight.setter
    def gross_weight(self, gross_weight):
        """Sets the gross_weight of this ProductSku.

        The default gross weight of current SKU. If not present, then switch back to the default value of product  # noqa: E501

        :param gross_weight: The gross_weight of this ProductSku.  # noqa: E501
        :type: float
        """

        self._gross_weight = gross_weight

    @property
    def shipping_cost(self):
        """Gets the shipping_cost of this ProductSku.  # noqa: E501

        The shipping cost of current SKU. Will overwrite product's.  # noqa: E501

        :return: The shipping_cost of this ProductSku.  # noqa: E501
        :rtype: float
        """
        return self._shipping_cost

    @shipping_cost.setter
    def shipping_cost(self, shipping_cost):
        """Sets the shipping_cost of this ProductSku.

        The shipping cost of current SKU. Will overwrite product's.  # noqa: E501

        :param shipping_cost: The shipping_cost of this ProductSku.  # noqa: E501
        :type: float
        """

        self._shipping_cost = shipping_cost

    @property
    def shipping_time(self):
        """Gets the shipping_time of this ProductSku.  # noqa: E501

        The days that take to ship and deliver to customer's door. Will overwrite product's.  # noqa: E501

        :return: The shipping_time of this ProductSku.  # noqa: E501
        :rtype: int
        """
        return self._shipping_time

    @shipping_time.setter
    def shipping_time(self, shipping_time):
        """Sets the shipping_time of this ProductSku.

        The days that take to ship and deliver to customer's door. Will overwrite product's.  # noqa: E501

        :param shipping_time: The shipping_time of this ProductSku.  # noqa: E501
        :type: int
        """

        self._shipping_time = shipping_time

    @property
    def model(self):
        """Gets the model of this ProductSku.  # noqa: E501

        The model of current sku.  # noqa: E501

        :return: The model of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ProductSku.

        The model of current sku.  # noqa: E501

        :param model: The model of this ProductSku.  # noqa: E501
        :type: str
        """

        self._model = model

    @property
    def spec(self):
        """Gets the spec of this ProductSku.  # noqa: E501

        The spec of current sku.  # noqa: E501

        :return: The spec of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this ProductSku.

        The spec of current sku.  # noqa: E501

        :param spec: The spec of this ProductSku.  # noqa: E501
        :type: str
        """

        self._spec = spec

    @property
    def customs_unit_code(self):
        """Gets the customs_unit_code of this ProductSku.  # noqa: E501

        aka customsUnitCodeSKU. The quantity unit code of current sku for customs purpose. Both Chinese or number are ok.  # noqa: E501

        :return: The customs_unit_code of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._customs_unit_code

    @customs_unit_code.setter
    def customs_unit_code(self, customs_unit_code):
        """Sets the customs_unit_code of this ProductSku.

        aka customsUnitCodeSKU. The quantity unit code of current sku for customs purpose. Both Chinese or number are ok.  # noqa: E501

        :param customs_unit_code: The customs_unit_code of this ProductSku.  # noqa: E501
        :type: str
        """

        self._customs_unit_code = customs_unit_code

    @property
    def customs_unit_code_package(self):
        """Gets the customs_unit_code_package of this ProductSku.  # noqa: E501

        The quantity unit code customs purpose. Declaration Unit, 申报单位.  # noqa: E501

        :return: The customs_unit_code_package of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._customs_unit_code_package

    @customs_unit_code_package.setter
    def customs_unit_code_package(self, customs_unit_code_package):
        """Sets the customs_unit_code_package of this ProductSku.

        The quantity unit code customs purpose. Declaration Unit, 申报单位.  # noqa: E501

        :param customs_unit_code_package: The customs_unit_code_package of this ProductSku.  # noqa: E501
        :type: str
        """

        self._customs_unit_code_package = customs_unit_code_package

    @property
    def customs_unit_code_weight(self):
        """Gets the customs_unit_code_weight of this ProductSku.  # noqa: E501

        The weight unit code for customs purpose.  # noqa: E501

        :return: The customs_unit_code_weight of this ProductSku.  # noqa: E501
        :rtype: str
        """
        return self._customs_unit_code_weight

    @customs_unit_code_weight.setter
    def customs_unit_code_weight(self, customs_unit_code_weight):
        """Sets the customs_unit_code_weight of this ProductSku.

        The weight unit code for customs purpose.  # noqa: E501

        :param customs_unit_code_weight: The customs_unit_code_weight of this ProductSku.  # noqa: E501
        :type: str
        """

        self._customs_unit_code_weight = customs_unit_code_weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductSku):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_connectors_cli
from nomad_connectors_cli.api.product_api import ProductApi  # noqa: E501
from nomad_connectors_cli.rest import ApiException


class TestProductApi(unittest.TestCase):
    """ProductApi unit test stubs"""

    def setUp(self):
        self.api = nomad_connectors_cli.api.product_api.ProductApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_product(self):
        """Test case for add_product

        addProduct  # noqa: E501
        """
        pass

    def test_delete_product(self):
        """Test case for delete_product

        deleteProduct  # noqa: E501
        """
        pass

    def test_get_products_by_field(self):
        """Test case for get_products_by_field

        getProductsByField  # noqa: E501
        """
        pass

    def test_update_product(self):
        """Test case for update_product

        updateProduct  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ApiResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'int',
        'message': 'str',
        'data': 'ApiResponseData',
        'connector_responses': 'list[ApiResponseConnectorResponse]',
        'response_time': 'int'
    }

    attribute_map = {
        'code': 'code',
        'message': 'message',
        'data': 'data',
        'connector_responses': 'connectorResponses',
        'response_time': 'responseTime'
    }

    def __init__(self, code=None, message=None, data=None, connector_responses=None, response_time=None):  # noqa: E501
        """ApiResponse - a model defined in OpenAPI"""  # noqa: E501

        self._code = None
        self._message = None
        self._data = None
        self._connector_responses = None
        self._response_time = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if message is not None:
            self.message = message
        if data is not None:
            self.data = data
        if connector_responses is not None:
            self.connector_responses = connector_responses
        if response_time is not None:
            self.response_time = response_time

    @property
    def code(self):
        """Gets the code of this ApiResponse.  # noqa: E501


        :return: The code of this ApiResponse.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ApiResponse.


        :param code: The code of this ApiResponse.  # noqa: E501
        :type: int
        """

        self._code = code

    @property
    def message(self):
        """Gets the message of this ApiResponse.  # noqa: E501


        :return: The message of this ApiResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ApiResponse.


        :param message: The message of this ApiResponse.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def data(self):
        """Gets the data of this ApiResponse.  # noqa: E501


        :return: The data of this ApiResponse.  # noqa: E501
        :rtype: ApiResponseData
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ApiResponse.


        :param data: The data of this ApiResponse.  # noqa: E501
        :type: ApiResponseData
        """

        self._data = data

    @property
    def connector_responses(self):
        """Gets the connector_responses of this ApiResponse.  # noqa: E501


        :return: The connector_responses of this ApiResponse.  # noqa: E501
        :rtype: list[ApiResponseConnectorResponse]
        """
        return self._connector_responses

    @connector_responses.setter
    def connector_responses(self, connector_responses):
        """Sets the connector_responses of this ApiResponse.


        :param connector_responses: The connector_responses of this ApiResponse.  # noqa: E501
        :type: list[ApiResponseConnectorResponse]
        """

        self._connector_responses = connector_responses

    @property
    def response_time(self):
        """Gets the response_time of this ApiResponse.  # noqa: E501

        The response time of current NomadMapping request, including sub-NomadMapping's. The time unit is millisecond. This 'responseTime' is different from the one in ApiResponseConnectorResponse, since our NomadMapping supports spawn mode, whose output will be replaced by its children's instead of its own.  # noqa: E501

        :return: The response_time of this ApiResponse.  # noqa: E501
        :rtype: int
        """
        return self._response_time

    @response_time.setter
    def response_time(self, response_time):
        """Sets the response_time of this ApiResponse.

        The response time of current NomadMapping request, including sub-NomadMapping's. The time unit is millisecond. This 'responseTime' is different from the one in ApiResponseConnectorResponse, since our NomadMapping supports spawn mode, whose output will be replaced by its children's instead of its own.  # noqa: E501

        :param response_time: The response_time of this ApiResponse.  # noqa: E501
        :type: int
        """

        self._response_time = response_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nomad_connectors_cli.api_client import ApiClient
from nomad_connectors_cli.exceptions import (
    ApiTypeError,
    ApiValueError
)


class OrderApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_order(self, store, order, **kwargs):  # noqa: E501
        """addOrder  # noqa: E501

        Creates a new order for products for this store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_order(store, order, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param Order order: Order details (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_order_with_http_info(store, order, **kwargs)  # noqa: E501
        else:
            (data) = self.add_order_with_http_info(store, order, **kwargs)  # noqa: E501
            return data

    def add_order_with_http_info(self, store, order, **kwargs):  # noqa: E501
        """addOrder  # noqa: E501

        Creates a new order for products for this store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_order_with_http_info(store, order, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param Order order: Order details (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['store', 'order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_order" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'store' is set
        if ('store' not in local_var_params or
                local_var_params['store'] is None):
            raise ApiValueError("Missing the required parameter `store` when calling `add_order`")  # noqa: E501
        # verify the required parameter 'order' is set
        if ('order' not in local_var_params or
                local_var_params['order'] is None):
            raise ApiValueError("Missing the required parameter `order` when calling `add_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store' in local_var_params:
            path_params['store'] = local_var_params['store']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'order' in local_var_params:
            body_params = local_var_params['order']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/envoy/order/{store}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cancel_order(self, store, order_id, **kwargs):  # noqa: E501
        """cancelOrder  # noqa: E501

        Attempts to cancel a created order, success will depend on platform support.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_order(store, order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param int order_id: ID of order to cancel. (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_order_with_http_info(store, order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_order_with_http_info(store, order_id, **kwargs)  # noqa: E501
            return data

    def cancel_order_with_http_info(self, store, order_id, **kwargs):  # noqa: E501
        """cancelOrder  # noqa: E501

        Attempts to cancel a created order, success will depend on platform support.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_order_with_http_info(store, order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param int order_id: ID of order to cancel. (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['store', 'order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_order" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'store' is set
        if ('store' not in local_var_params or
                local_var_params['store'] is None):
            raise ApiValueError("Missing the required parameter `store` when calling `cancel_order`")  # noqa: E501
        # verify the required parameter 'order_id' is set
        if ('order_id' not in local_var_params or
                local_var_params['order_id'] is None):
            raise ApiValueError("Missing the required parameter `order_id` when calling `cancel_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store' in local_var_params:
            path_params['store'] = local_var_params['store']  # noqa: E501

        query_params = []
        if 'order_id' in local_var_params:
            query_params.append(('order_id', local_var_params['order_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/envoy/order/{store}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order_by_field(self, store, **kwargs):  # noqa: E501
        """getOrderByField  # noqa: E501

        Requests a specific order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_by_field(store, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param str order_id: Order ID ref (odoo platform) for order to get.
        :param str client_order_ref: Client order ref (third party platform, same as Order.entity)
        :param str status: order status, 6 available options are [WAIT_BUYER_PAY, WAIT_SELLER_SEND_GOODS, WAIT_BUYER_CONFIRM_GOODS, TRADE_SUCCESS, TRADE_CLOSED ,TRADE_REFUND]
        :param str created_range: The time range of order creation, use ISO_8601 format here, e.g. 2007-03-01T13:00:00Z/2008-05-11T15:30:00Z
        :param str updated_range: The time range of order update, use ISO_8601 format here, e.g. 2007-03-01T13:00:00Z/2008-05-11T15:30:00Z
        :param int page_no: Page number
        :param int page_size: Page size
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_order_by_field_with_http_info(store, **kwargs)  # noqa: E501
        else:
            (data) = self.get_order_by_field_with_http_info(store, **kwargs)  # noqa: E501
            return data

    def get_order_by_field_with_http_info(self, store, **kwargs):  # noqa: E501
        """getOrderByField  # noqa: E501

        Requests a specific order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_by_field_with_http_info(store, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param str order_id: Order ID ref (odoo platform) for order to get.
        :param str client_order_ref: Client order ref (third party platform, same as Order.entity)
        :param str status: order status, 6 available options are [WAIT_BUYER_PAY, WAIT_SELLER_SEND_GOODS, WAIT_BUYER_CONFIRM_GOODS, TRADE_SUCCESS, TRADE_CLOSED ,TRADE_REFUND]
        :param str created_range: The time range of order creation, use ISO_8601 format here, e.g. 2007-03-01T13:00:00Z/2008-05-11T15:30:00Z
        :param str updated_range: The time range of order update, use ISO_8601 format here, e.g. 2007-03-01T13:00:00Z/2008-05-11T15:30:00Z
        :param int page_no: Page number
        :param int page_size: Page size
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['store', 'order_id', 'client_order_ref', 'status', 'created_range', 'updated_range', 'page_no', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order_by_field" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'store' is set
        if ('store' not in local_var_params or
                local_var_params['store'] is None):
            raise ApiValueError("Missing the required parameter `store` when calling `get_order_by_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store' in local_var_params:
            path_params['store'] = local_var_params['store']  # noqa: E501

        query_params = []
        if 'order_id' in local_var_params:
            query_params.append(('order_id', local_var_params['order_id']))  # noqa: E501
        if 'client_order_ref' in local_var_params:
            query_params.append(('client_order_ref', local_var_params['client_order_ref']))  # noqa: E501
        if 'status' in local_var_params:
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'created_range' in local_var_params:
            query_params.append(('created_range', local_var_params['created_range']))  # noqa: E501
        if 'updated_range' in local_var_params:
            query_params.append(('updated_range', local_var_params['updated_range']))  # noqa: E501
        if 'page_no' in local_var_params:
            query_params.append(('page_no', local_var_params['page_no']))  # noqa: E501
        if 'page_size' in local_var_params:
            query_params.append(('page_size', local_var_params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/envoy/order/{store}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_order(self, store, order, **kwargs):  # noqa: E501
        """updateOrder  # noqa: E501

        Update the shipping status of an order for this store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_order(store, order, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param Order order: Order details (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_order_with_http_info(store, order, **kwargs)  # noqa: E501
        else:
            (data) = self.update_order_with_http_info(store, order, **kwargs)  # noqa: E501
            return data

    def update_order_with_http_info(self, store, order, **kwargs):  # noqa: E501
        """updateOrder  # noqa: E501

        Update the shipping status of an order for this store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_order_with_http_info(store, order, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store: ID of the store. (required)
        :param Order order: Order details (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['store', 'order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_order" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'store' is set
        if ('store' not in local_var_params or
                local_var_params['store'] is None):
            raise ApiValueError("Missing the required parameter `store` when calling `update_order`")  # noqa: E501
        # verify the required parameter 'order' is set
        if ('order' not in local_var_params or
                local_var_params['order'] is None):
            raise ApiValueError("Missing the required parameter `order` when calling `update_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store' in local_var_params:
            path_params['store'] = local_var_params['store']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'order' in local_var_params:
            body_params = local_var_params['order']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/envoy/order/{store}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.1.0"

# import apis into sdk package
from nomad_connectors_cli.api.customs_callback_api import CustomsCallbackApi
from nomad_connectors_cli.api.customs_order_api import CustomsOrderApi
from nomad_connectors_cli.api.customs_payment_api import CustomsPaymentApi
from nomad_connectors_cli.api.customs_product_api import CustomsProductApi
from nomad_connectors_cli.api.order_api import OrderApi
from nomad_connectors_cli.api.product_api import ProductApi
from nomad_connectors_cli.api.ship_api import ShipApi

# import ApiClient
from nomad_connectors_cli.api_client import ApiClient
from nomad_connectors_cli.configuration import Configuration
from nomad_connectors_cli.exceptions import OpenApiException
from nomad_connectors_cli.exceptions import ApiTypeError
from nomad_connectors_cli.exceptions import ApiValueError
from nomad_connectors_cli.exceptions import ApiKeyError
from nomad_connectors_cli.exceptions import ApiException
# import models into sdk package
from nomad_connectors_cli.models.address import Address
from nomad_connectors_cli.models.api_response import ApiResponse
from nomad_connectors_cli.models.api_response_connector_response import ApiResponseConnectorResponse
from nomad_connectors_cli.models.api_response_data import ApiResponseData
from nomad_connectors_cli.models.customs_declaration_result import CustomsDeclarationResult
from nomad_connectors_cli.models.dimension import Dimension
from nomad_connectors_cli.models.goldjet import Goldjet
from nomad_connectors_cli.models.images import Images
from nomad_connectors_cli.models.order import Order
from nomad_connectors_cli.models.order_product import OrderProduct
from nomad_connectors_cli.models.package import Package
from nomad_connectors_cli.models.package_item import PackageItem
from nomad_connectors_cli.models.product import Product
from nomad_connectors_cli.models.product_sku import ProductSku




# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nomad_connectors_cli.api_client import ApiClient
from nomad_connectors_cli.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ShipApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_ship(self, carrier, order_ref, **kwargs):  # noqa: E501
        """cancelShip  # noqa: E501

        Attempts to cancel a created waybill, success will depend on carrier support.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_ship(carrier, order_ref, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str carrier: String name of carrier (required)
        :param str order_ref: String name of order ref (by Odoo) (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_ship_with_http_info(carrier, order_ref, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_ship_with_http_info(carrier, order_ref, **kwargs)  # noqa: E501
            return data

    def cancel_ship_with_http_info(self, carrier, order_ref, **kwargs):  # noqa: E501
        """cancelShip  # noqa: E501

        Attempts to cancel a created waybill, success will depend on carrier support.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_ship_with_http_info(carrier, order_ref, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str carrier: String name of carrier (required)
        :param str order_ref: String name of order ref (by Odoo) (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['carrier', 'order_ref']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_ship" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'carrier' is set
        if ('carrier' not in local_var_params or
                local_var_params['carrier'] is None):
            raise ApiValueError("Missing the required parameter `carrier` when calling `cancel_ship`")  # noqa: E501
        # verify the required parameter 'order_ref' is set
        if ('order_ref' not in local_var_params or
                local_var_params['order_ref'] is None):
            raise ApiValueError("Missing the required parameter `order_ref` when calling `cancel_ship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'carrier' in local_var_params:
            path_params['carrier'] = local_var_params['carrier']  # noqa: E501
        if 'order_ref' in local_var_params:
            path_params['order_ref'] = local_var_params['order_ref']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/pilot/ship/{carrier}/order/{order_ref}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_ship(self, carrier, order_ref, **kwargs):  # noqa: E501
        """queryShip  # noqa: E501

        Query the status of an order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_ship(carrier, order_ref, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str carrier: String name of carrier (required)
        :param str order_ref: order ref (by Odoo) (required)
        :param str seller_order_ref: order ref (by third party retailers, e.g. Youzan)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_ship_with_http_info(carrier, order_ref, **kwargs)  # noqa: E501
        else:
            (data) = self.query_ship_with_http_info(carrier, order_ref, **kwargs)  # noqa: E501
            return data

    def query_ship_with_http_info(self, carrier, order_ref, **kwargs):  # noqa: E501
        """queryShip  # noqa: E501

        Query the status of an order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_ship_with_http_info(carrier, order_ref, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str carrier: String name of carrier (required)
        :param str order_ref: order ref (by Odoo) (required)
        :param str seller_order_ref: order ref (by third party retailers, e.g. Youzan)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['carrier', 'order_ref', 'seller_order_ref']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_ship" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'carrier' is set
        if ('carrier' not in local_var_params or
                local_var_params['carrier'] is None):
            raise ApiValueError("Missing the required parameter `carrier` when calling `query_ship`")  # noqa: E501
        # verify the required parameter 'order_ref' is set
        if ('order_ref' not in local_var_params or
                local_var_params['order_ref'] is None):
            raise ApiValueError("Missing the required parameter `order_ref` when calling `query_ship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'carrier' in local_var_params:
            path_params['carrier'] = local_var_params['carrier']  # noqa: E501
        if 'order_ref' in local_var_params:
            path_params['order_ref'] = local_var_params['order_ref']  # noqa: E501

        query_params = []
        if 'seller_order_ref' in local_var_params:
            query_params.append(('seller_order_ref', local_var_params['seller_order_ref']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/pilot/ship/{carrier}/order/{order_ref}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ship(self, carrier, package, **kwargs):  # noqa: E501
        """ship  # noqa: E501

        Requests waybill creation from specified carrier. Receives waybill details in return, most carriers provide id and PDF packing label  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ship(carrier, package, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str carrier: Carrier to ship with (required)
        :param Package package: Package to ship (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.ship_with_http_info(carrier, package, **kwargs)  # noqa: E501
        else:
            (data) = self.ship_with_http_info(carrier, package, **kwargs)  # noqa: E501
            return data

    def ship_with_http_info(self, carrier, package, **kwargs):  # noqa: E501
        """ship  # noqa: E501

        Requests waybill creation from specified carrier. Receives waybill details in return, most carriers provide id and PDF packing label  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ship_with_http_info(carrier, package, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str carrier: Carrier to ship with (required)
        :param Package package: Package to ship (required)
        :return: ApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['carrier', 'package']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ship" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'carrier' is set
        if ('carrier' not in local_var_params or
                local_var_params['carrier'] is None):
            raise ApiValueError("Missing the required parameter `carrier` when calling `ship`")  # noqa: E501
        # verify the required parameter 'package' is set
        if ('package' not in local_var_params or
                local_var_params['package'] is None):
            raise ApiValueError("Missing the required parameter `package` when calling `ship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'carrier' in local_var_params:
            path_params['carrier'] = local_var_params['carrier']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'package' in local_var_params:
            body_params = local_var_params['package']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key', 'ca_stage']  # noqa: E501

        return self.api_client.call_api(
            '/pilot/ship/{carrier}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class CustomsDeclarationResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'region': 'str',
        'declaration_type': 'str',
        'declaration_number': 'str',
        'client_order_ref': 'str',
        'order_id': 'str',
        'product_sku_number': 'str',
        'product_barcode': 'str',
        'orig_message': 'str',
        'is_regsitered': 'bool'
    }

    attribute_map = {
        'region': 'region',
        'declaration_type': 'declarationType',
        'declaration_number': 'declarationNumber',
        'client_order_ref': 'clientOrderRef',
        'order_id': 'orderId',
        'product_sku_number': 'product_sku_number',
        'product_barcode': 'product_barcode',
        'orig_message': 'origMessage',
        'is_regsitered': 'isRegsitered'
    }

    def __init__(self, region=None, declaration_type=None, declaration_number=None, client_order_ref=None, order_id=None, product_sku_number=None, product_barcode=None, orig_message=None, is_regsitered=None):  # noqa: E501
        """CustomsDeclarationResult - a model defined in OpenAPI"""  # noqa: E501

        self._region = None
        self._declaration_type = None
        self._declaration_number = None
        self._client_order_ref = None
        self._order_id = None
        self._product_sku_number = None
        self._product_barcode = None
        self._orig_message = None
        self._is_regsitered = None
        self.discriminator = None

        if region is not None:
            self.region = region
        if declaration_type is not None:
            self.declaration_type = declaration_type
        if declaration_number is not None:
            self.declaration_number = declaration_number
        if client_order_ref is not None:
            self.client_order_ref = client_order_ref
        if order_id is not None:
            self.order_id = order_id
        if product_sku_number is not None:
            self.product_sku_number = product_sku_number
        if product_barcode is not None:
            self.product_barcode = product_barcode
        if orig_message is not None:
            self.orig_message = orig_message
        if is_regsitered is not None:
            self.is_regsitered = is_regsitered

    @property
    def region(self):
        """Gets the region of this CustomsDeclarationResult.  # noqa: E501

        The sender customs port of current callback.  # noqa: E501

        :return: The region of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this CustomsDeclarationResult.

        The sender customs port of current callback.  # noqa: E501

        :param region: The region of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def declaration_type(self):
        """Gets the declaration_type of this CustomsDeclarationResult.  # noqa: E501

        could be one of order/product/company/brand  # noqa: E501

        :return: The declaration_type of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._declaration_type

    @declaration_type.setter
    def declaration_type(self, declaration_type):
        """Sets the declaration_type of this CustomsDeclarationResult.

        could be one of order/product/company/brand  # noqa: E501

        :param declaration_type: The declaration_type of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._declaration_type = declaration_type

    @property
    def declaration_number(self):
        """Gets the declaration_number of this CustomsDeclarationResult.  # noqa: E501

        1. an unique number given by customs when the order/product filing is successful, otherwise will be empty   # noqa: E501

        :return: The declaration_number of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._declaration_number

    @declaration_number.setter
    def declaration_number(self, declaration_number):
        """Sets the declaration_number of this CustomsDeclarationResult.

        1. an unique number given by customs when the order/product filing is successful, otherwise will be empty   # noqa: E501

        :param declaration_number: The declaration_number of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._declaration_number = declaration_number

    @property
    def client_order_ref(self):
        """Gets the client_order_ref of this CustomsDeclarationResult.  # noqa: E501

        Client order ref (third party platform)  # noqa: E501

        :return: The client_order_ref of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._client_order_ref

    @client_order_ref.setter
    def client_order_ref(self, client_order_ref):
        """Sets the client_order_ref of this CustomsDeclarationResult.

        Client order ref (third party platform)  # noqa: E501

        :param client_order_ref: The client_order_ref of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._client_order_ref = client_order_ref

    @property
    def order_id(self):
        """Gets the order_id of this CustomsDeclarationResult.  # noqa: E501

        Order ID ref (Odoo platform).  # noqa: E501

        :return: The order_id of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this CustomsDeclarationResult.

        Order ID ref (Odoo platform).  # noqa: E501

        :param order_id: The order_id of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def product_sku_number(self):
        """Gets the product_sku_number of this CustomsDeclarationResult.  # noqa: E501

        the sku number of current product/sku  # noqa: E501

        :return: The product_sku_number of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._product_sku_number

    @product_sku_number.setter
    def product_sku_number(self, product_sku_number):
        """Sets the product_sku_number of this CustomsDeclarationResult.

        the sku number of current product/sku  # noqa: E501

        :param product_sku_number: The product_sku_number of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._product_sku_number = product_sku_number

    @property
    def product_barcode(self):
        """Gets the product_barcode of this CustomsDeclarationResult.  # noqa: E501

        the barcode of current product/sku  # noqa: E501

        :return: The product_barcode of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._product_barcode

    @product_barcode.setter
    def product_barcode(self, product_barcode):
        """Sets the product_barcode of this CustomsDeclarationResult.

        the barcode of current product/sku  # noqa: E501

        :param product_barcode: The product_barcode of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._product_barcode = product_barcode

    @property
    def orig_message(self):
        """Gets the orig_message of this CustomsDeclarationResult.  # noqa: E501

        Original message from the customs  # noqa: E501

        :return: The orig_message of this CustomsDeclarationResult.  # noqa: E501
        :rtype: str
        """
        return self._orig_message

    @orig_message.setter
    def orig_message(self, orig_message):
        """Sets the orig_message of this CustomsDeclarationResult.

        Original message from the customs  # noqa: E501

        :param orig_message: The orig_message of this CustomsDeclarationResult.  # noqa: E501
        :type: str
        """

        self._orig_message = orig_message

    @property
    def is_regsitered(self):
        """Gets the is_regsitered of this CustomsDeclarationResult.  # noqa: E501

        Return True if current order/product/.. already registered  # noqa: E501

        :return: The is_regsitered of this CustomsDeclarationResult.  # noqa: E501
        :rtype: bool
        """
        return self._is_regsitered

    @is_regsitered.setter
    def is_regsitered(self, is_regsitered):
        """Sets the is_regsitered of this CustomsDeclarationResult.

        Return True if current order/product/.. already registered  # noqa: E501

        :param is_regsitered: The is_regsitered of this CustomsDeclarationResult.  # noqa: E501
        :type: bool
        """

        self._is_regsitered = is_regsitered

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomsDeclarationResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Product(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'product_id': 'str',
        'name': 'str',
        'name_en': 'str',
        'skus': 'list[ProductSku]',
        'currency': 'str',
        'mass_unit': 'str',
        'time_unit': 'str',
        'barcode': 'str',
        'description': 'str',
        'price': 'float',
        'rrp': 'float',
        'group_buying_price': 'float',
        'net_weight': 'float',
        'gross_weight': 'float',
        'images': 'Images',
        'is_onsale': 'bool',
        'status': 'str',
        'category': 'list[str]',
        'vendor': 'str',
        'country': 'str',
        'shelf_life': 'float',
        'created_at': 'str',
        'updated_at': 'str',
        'logistics_mode': 'str',
        'shipping_cost': 'float',
        'shipping_time': 'int',
        'hs_code': 'str',
        'personal_postal_articles_tax': 'str',
        'ingredient': 'str',
        'model': 'str',
        'spec': 'str',
        'warranty_period': 'int'
    }

    attribute_map = {
        'product_id': 'productId',
        'name': 'name',
        'name_en': 'nameEn',
        'skus': 'skus',
        'currency': 'currency',
        'mass_unit': 'massUnit',
        'time_unit': 'timeUnit',
        'barcode': 'barcode',
        'description': 'description',
        'price': 'price',
        'rrp': 'rrp',
        'group_buying_price': 'groupBuyingPrice',
        'net_weight': 'netWeight',
        'gross_weight': 'grossWeight',
        'images': 'images',
        'is_onsale': 'isOnsale',
        'status': 'status',
        'category': 'category',
        'vendor': 'vendor',
        'country': 'country',
        'shelf_life': 'shelfLife',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'logistics_mode': 'logisticsMode',
        'shipping_cost': 'shippingCost',
        'shipping_time': 'shippingTime',
        'hs_code': 'hsCode',
        'personal_postal_articles_tax': 'personalPostalArticlesTax',
        'ingredient': 'ingredient',
        'model': 'model',
        'spec': 'spec',
        'warranty_period': 'warrantyPeriod'
    }

    def __init__(self, product_id=None, name=None, name_en=None, skus=None, currency='RMB', mass_unit='Kilogram', time_unit=None, barcode=None, description=None, price=None, rrp=None, group_buying_price=None, net_weight=None, gross_weight=None, images=None, is_onsale=None, status='draft', category=None, vendor=None, country=None, shelf_life=None, created_at=None, updated_at=None, logistics_mode=None, shipping_cost=None, shipping_time=None, hs_code=None, personal_postal_articles_tax=None, ingredient=None, model=None, spec=None, warranty_period=365):  # noqa: E501
        """Product - a model defined in OpenAPI"""  # noqa: E501

        self._product_id = None
        self._name = None
        self._name_en = None
        self._skus = None
        self._currency = None
        self._mass_unit = None
        self._time_unit = None
        self._barcode = None
        self._description = None
        self._price = None
        self._rrp = None
        self._group_buying_price = None
        self._net_weight = None
        self._gross_weight = None
        self._images = None
        self._is_onsale = None
        self._status = None
        self._category = None
        self._vendor = None
        self._country = None
        self._shelf_life = None
        self._created_at = None
        self._updated_at = None
        self._logistics_mode = None
        self._shipping_cost = None
        self._shipping_time = None
        self._hs_code = None
        self._personal_postal_articles_tax = None
        self._ingredient = None
        self._model = None
        self._spec = None
        self._warranty_period = None
        self.discriminator = None

        if product_id is not None:
            self.product_id = product_id
        if name is not None:
            self.name = name
        if name_en is not None:
            self.name_en = name_en
        if skus is not None:
            self.skus = skus
        self.currency = currency
        self.mass_unit = mass_unit
        if time_unit is not None:
            self.time_unit = time_unit
        if barcode is not None:
            self.barcode = barcode
        if description is not None:
            self.description = description
        if price is not None:
            self.price = price
        if rrp is not None:
            self.rrp = rrp
        if group_buying_price is not None:
            self.group_buying_price = group_buying_price
        if net_weight is not None:
            self.net_weight = net_weight
        if gross_weight is not None:
            self.gross_weight = gross_weight
        if images is not None:
            self.images = images
        if is_onsale is not None:
            self.is_onsale = is_onsale
        if status is not None:
            self.status = status
        if category is not None:
            self.category = category
        if vendor is not None:
            self.vendor = vendor
        if country is not None:
            self.country = country
        if shelf_life is not None:
            self.shelf_life = shelf_life
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if logistics_mode is not None:
            self.logistics_mode = logistics_mode
        if shipping_cost is not None:
            self.shipping_cost = shipping_cost
        if shipping_time is not None:
            self.shipping_time = shipping_time
        if hs_code is not None:
            self.hs_code = hs_code
        if personal_postal_articles_tax is not None:
            self.personal_postal_articles_tax = personal_postal_articles_tax
        if ingredient is not None:
            self.ingredient = ingredient
        if model is not None:
            self.model = model
        if spec is not None:
            self.spec = spec
        if warranty_period is not None:
            self.warranty_period = warranty_period

    @property
    def product_id(self):
        """Gets the product_id of this Product.  # noqa: E501

        product ID of third parties.  # noqa: E501

        :return: The product_id of this Product.  # noqa: E501
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this Product.

        product ID of third parties.  # noqa: E501

        :param product_id: The product_id of this Product.  # noqa: E501
        :type: str
        """

        self._product_id = product_id

    @property
    def name(self):
        """Gets the name of this Product.  # noqa: E501

        Default name, usually it's Chinese.  # noqa: E501

        :return: The name of this Product.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Product.

        Default name, usually it's Chinese.  # noqa: E501

        :param name: The name of this Product.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def name_en(self):
        """Gets the name_en of this Product.  # noqa: E501

        English name, should be optional  # noqa: E501

        :return: The name_en of this Product.  # noqa: E501
        :rtype: str
        """
        return self._name_en

    @name_en.setter
    def name_en(self, name_en):
        """Sets the name_en of this Product.

        English name, should be optional  # noqa: E501

        :param name_en: The name_en of this Product.  # noqa: E501
        :type: str
        """

        self._name_en = name_en

    @property
    def skus(self):
        """Gets the skus of this Product.  # noqa: E501

        all SKU in a product  # noqa: E501

        :return: The skus of this Product.  # noqa: E501
        :rtype: list[ProductSku]
        """
        return self._skus

    @skus.setter
    def skus(self, skus):
        """Sets the skus of this Product.

        all SKU in a product  # noqa: E501

        :param skus: The skus of this Product.  # noqa: E501
        :type: list[ProductSku]
        """

        self._skus = skus

    @property
    def currency(self):
        """Gets the currency of this Product.  # noqa: E501

        The currency used in current product, it makes sense if we declare it explicity.  # noqa: E501

        :return: The currency of this Product.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Product.

        The currency used in current product, it makes sense if we declare it explicity.  # noqa: E501

        :param currency: The currency of this Product.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def mass_unit(self):
        """Gets the mass_unit of this Product.  # noqa: E501

        weight unit in current product.  # noqa: E501

        :return: The mass_unit of this Product.  # noqa: E501
        :rtype: str
        """
        return self._mass_unit

    @mass_unit.setter
    def mass_unit(self, mass_unit):
        """Sets the mass_unit of this Product.

        weight unit in current product.  # noqa: E501

        :param mass_unit: The mass_unit of this Product.  # noqa: E501
        :type: str
        """
        if mass_unit is None:
            raise ValueError("Invalid value for `mass_unit`, must not be `None`")  # noqa: E501

        self._mass_unit = mass_unit

    @property
    def time_unit(self):
        """Gets the time_unit of this Product.  # noqa: E501

        time unit in current product.  # noqa: E501

        :return: The time_unit of this Product.  # noqa: E501
        :rtype: str
        """
        return self._time_unit

    @time_unit.setter
    def time_unit(self, time_unit):
        """Sets the time_unit of this Product.

        time unit in current product.  # noqa: E501

        :param time_unit: The time_unit of this Product.  # noqa: E501
        :type: str
        """

        self._time_unit = time_unit

    @property
    def barcode(self):
        """Gets the barcode of this Product.  # noqa: E501


        :return: The barcode of this Product.  # noqa: E501
        :rtype: str
        """
        return self._barcode

    @barcode.setter
    def barcode(self, barcode):
        """Sets the barcode of this Product.


        :param barcode: The barcode of this Product.  # noqa: E501
        :type: str
        """

        self._barcode = barcode

    @property
    def description(self):
        """Gets the description of this Product.  # noqa: E501


        :return: The description of this Product.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Product.


        :param description: The description of this Product.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def price(self):
        """Gets the price of this Product.  # noqa: E501

        The default selling price of current product.  # noqa: E501

        :return: The price of this Product.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this Product.

        The default selling price of current product.  # noqa: E501

        :param price: The price of this Product.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def rrp(self):
        """Gets the rrp of this Product.  # noqa: E501

        recommended retail price  # noqa: E501

        :return: The rrp of this Product.  # noqa: E501
        :rtype: float
        """
        return self._rrp

    @rrp.setter
    def rrp(self, rrp):
        """Sets the rrp of this Product.

        recommended retail price  # noqa: E501

        :param rrp: The rrp of this Product.  # noqa: E501
        :type: float
        """

        self._rrp = rrp

    @property
    def group_buying_price(self):
        """Gets the group_buying_price of this Product.  # noqa: E501

        group buying price  # noqa: E501

        :return: The group_buying_price of this Product.  # noqa: E501
        :rtype: float
        """
        return self._group_buying_price

    @group_buying_price.setter
    def group_buying_price(self, group_buying_price):
        """Sets the group_buying_price of this Product.

        group buying price  # noqa: E501

        :param group_buying_price: The group_buying_price of this Product.  # noqa: E501
        :type: float
        """

        self._group_buying_price = group_buying_price

    @property
    def net_weight(self):
        """Gets the net_weight of this Product.  # noqa: E501

        The default net weight of current product.  # noqa: E501

        :return: The net_weight of this Product.  # noqa: E501
        :rtype: float
        """
        return self._net_weight

    @net_weight.setter
    def net_weight(self, net_weight):
        """Sets the net_weight of this Product.

        The default net weight of current product.  # noqa: E501

        :param net_weight: The net_weight of this Product.  # noqa: E501
        :type: float
        """

        self._net_weight = net_weight

    @property
    def gross_weight(self):
        """Gets the gross_weight of this Product.  # noqa: E501

        The default gross weight of current product.  # noqa: E501

        :return: The gross_weight of this Product.  # noqa: E501
        :rtype: float
        """
        return self._gross_weight

    @gross_weight.setter
    def gross_weight(self, gross_weight):
        """Sets the gross_weight of this Product.

        The default gross weight of current product.  # noqa: E501

        :param gross_weight: The gross_weight of this Product.  # noqa: E501
        :type: float
        """

        self._gross_weight = gross_weight

    @property
    def images(self):
        """Gets the images of this Product.  # noqa: E501


        :return: The images of this Product.  # noqa: E501
        :rtype: Images
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this Product.


        :param images: The images of this Product.  # noqa: E501
        :type: Images
        """

        self._images = images

    @property
    def is_onsale(self):
        """Gets the is_onsale of this Product.  # noqa: E501

        if a product/sku is on sale.  # noqa: E501

        :return: The is_onsale of this Product.  # noqa: E501
        :rtype: bool
        """
        return self._is_onsale

    @is_onsale.setter
    def is_onsale(self, is_onsale):
        """Sets the is_onsale of this Product.

        if a product/sku is on sale.  # noqa: E501

        :param is_onsale: The is_onsale of this Product.  # noqa: E501
        :type: bool
        """

        self._is_onsale = is_onsale

    @property
    def status(self):
        """Gets the status of this Product.  # noqa: E501

        The status of a product in a store (more like a post) , could be draft/to_check/published/deleted/revoked. This field 'status' has priority over 'is_onsale'  # noqa: E501

        :return: The status of this Product.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Product.

        The status of a product in a store (more like a post) , could be draft/to_check/published/deleted/revoked. This field 'status' has priority over 'is_onsale'  # noqa: E501

        :param status: The status of this Product.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def category(self):
        """Gets the category of this Product.  # noqa: E501

        The category of current product, and the platform may or may not require fixed categories data  # noqa: E501

        :return: The category of this Product.  # noqa: E501
        :rtype: list[str]
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Product.

        The category of current product, and the platform may or may not require fixed categories data  # noqa: E501

        :param category: The category of this Product.  # noqa: E501
        :type: list[str]
        """

        self._category = category

    @property
    def vendor(self):
        """Gets the vendor of this Product.  # noqa: E501

        The name of the product vendor  # noqa: E501

        :return: The vendor of this Product.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this Product.

        The name of the product vendor  # noqa: E501

        :param vendor: The vendor of this Product.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def country(self):
        """Gets the country of this Product.  # noqa: E501

        The country of origin.  # noqa: E501

        :return: The country of this Product.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Product.

        The country of origin.  # noqa: E501

        :param country: The country of this Product.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def shelf_life(self):
        """Gets the shelf_life of this Product.  # noqa: E501

        How long could we keep current product on the shelf.  # noqa: E501

        :return: The shelf_life of this Product.  # noqa: E501
        :rtype: float
        """
        return self._shelf_life

    @shelf_life.setter
    def shelf_life(self, shelf_life):
        """Sets the shelf_life of this Product.

        How long could we keep current product on the shelf.  # noqa: E501

        :param shelf_life: The shelf_life of this Product.  # noqa: E501
        :type: float
        """

        self._shelf_life = shelf_life

    @property
    def created_at(self):
        """Gets the created_at of this Product.  # noqa: E501

        The time that when current product was created, and should be ISO 8601 format.  # noqa: E501

        :return: The created_at of this Product.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Product.

        The time that when current product was created, and should be ISO 8601 format.  # noqa: E501

        :param created_at: The created_at of this Product.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Product.  # noqa: E501

        The time that when the last time current product was updated, and should be ISO 8601 format.  # noqa: E501

        :return: The updated_at of this Product.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Product.

        The time that when the last time current product was updated, and should be ISO 8601 format.  # noqa: E501

        :param updated_at: The updated_at of this Product.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def logistics_mode(self):
        """Gets the logistics_mode of this Product.  # noqa: E501

        logistics mode of current product.  # noqa: E501

        :return: The logistics_mode of this Product.  # noqa: E501
        :rtype: str
        """
        return self._logistics_mode

    @logistics_mode.setter
    def logistics_mode(self, logistics_mode):
        """Sets the logistics_mode of this Product.

        logistics mode of current product.  # noqa: E501

        :param logistics_mode: The logistics_mode of this Product.  # noqa: E501
        :type: str
        """

        self._logistics_mode = logistics_mode

    @property
    def shipping_cost(self):
        """Gets the shipping_cost of this Product.  # noqa: E501

        The shipping cost of current product.  # noqa: E501

        :return: The shipping_cost of this Product.  # noqa: E501
        :rtype: float
        """
        return self._shipping_cost

    @shipping_cost.setter
    def shipping_cost(self, shipping_cost):
        """Sets the shipping_cost of this Product.

        The shipping cost of current product.  # noqa: E501

        :param shipping_cost: The shipping_cost of this Product.  # noqa: E501
        :type: float
        """

        self._shipping_cost = shipping_cost

    @property
    def shipping_time(self):
        """Gets the shipping_time of this Product.  # noqa: E501

        The days that take to ship and deliver to customer's door  # noqa: E501

        :return: The shipping_time of this Product.  # noqa: E501
        :rtype: int
        """
        return self._shipping_time

    @shipping_time.setter
    def shipping_time(self, shipping_time):
        """Sets the shipping_time of this Product.

        The days that take to ship and deliver to customer's door  # noqa: E501

        :param shipping_time: The shipping_time of this Product.  # noqa: E501
        :type: int
        """

        self._shipping_time = shipping_time

    @property
    def hs_code(self):
        """Gets the hs_code of this Product.  # noqa: E501

        The Harmonized Commodity Description and Coding System (HS code) of the tariff nomenclature is an international standardised system of names and numbers for the classification of commodities. The HS code system is based on a 6-digit nomenclature.  # noqa: E501

        :return: The hs_code of this Product.  # noqa: E501
        :rtype: str
        """
        return self._hs_code

    @hs_code.setter
    def hs_code(self, hs_code):
        """Sets the hs_code of this Product.

        The Harmonized Commodity Description and Coding System (HS code) of the tariff nomenclature is an international standardised system of names and numbers for the classification of commodities. The HS code system is based on a 6-digit nomenclature.  # noqa: E501

        :param hs_code: The hs_code of this Product.  # noqa: E501
        :type: str
        """

        self._hs_code = hs_code

    @property
    def personal_postal_articles_tax(self):
        """Gets the personal_postal_articles_tax of this Product.  # noqa: E501

        行邮税。Chinese version of parcel tax  # noqa: E501

        :return: The personal_postal_articles_tax of this Product.  # noqa: E501
        :rtype: str
        """
        return self._personal_postal_articles_tax

    @personal_postal_articles_tax.setter
    def personal_postal_articles_tax(self, personal_postal_articles_tax):
        """Sets the personal_postal_articles_tax of this Product.

        行邮税。Chinese version of parcel tax  # noqa: E501

        :param personal_postal_articles_tax: The personal_postal_articles_tax of this Product.  # noqa: E501
        :type: str
        """

        self._personal_postal_articles_tax = personal_postal_articles_tax

    @property
    def ingredient(self):
        """Gets the ingredient of this Product.  # noqa: E501

        The ingredient of current product.  # noqa: E501

        :return: The ingredient of this Product.  # noqa: E501
        :rtype: str
        """
        return self._ingredient

    @ingredient.setter
    def ingredient(self, ingredient):
        """Sets the ingredient of this Product.

        The ingredient of current product.  # noqa: E501

        :param ingredient: The ingredient of this Product.  # noqa: E501
        :type: str
        """

        self._ingredient = ingredient

    @property
    def model(self):
        """Gets the model of this Product.  # noqa: E501

        The model of current product.  # noqa: E501

        :return: The model of this Product.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this Product.

        The model of current product.  # noqa: E501

        :param model: The model of this Product.  # noqa: E501
        :type: str
        """

        self._model = model

    @property
    def spec(self):
        """Gets the spec of this Product.  # noqa: E501

        The spec of current product.  # noqa: E501

        :return: The spec of this Product.  # noqa: E501
        :rtype: str
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this Product.

        The spec of current product.  # noqa: E501

        :param spec: The spec of this Product.  # noqa: E501
        :type: str
        """

        self._spec = spec

    @property
    def warranty_period(self):
        """Gets the warranty_period of this Product.  # noqa: E501

        The warranty period of current product, time unit is day  # noqa: E501

        :return: The warranty_period of this Product.  # noqa: E501
        :rtype: int
        """
        return self._warranty_period

    @warranty_period.setter
    def warranty_period(self, warranty_period):
        """Sets the warranty_period of this Product.

        The warranty period of current product, time unit is day  # noqa: E501

        :param warranty_period: The warranty_period of this Product.  # noqa: E501
        :type: int
        """

        self._warranty_period = warranty_period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Product):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class OrderProduct(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'product': 'Product',
        'quantity': 'int',
        'price': 'float',
        'tax': 'float'
    }

    attribute_map = {
        'product': 'product',
        'quantity': 'quantity',
        'price': 'price',
        'tax': 'tax'
    }

    def __init__(self, product=None, quantity=None, price=None, tax=None):  # noqa: E501
        """OrderProduct - a model defined in OpenAPI"""  # noqa: E501

        self._product = None
        self._quantity = None
        self._price = None
        self._tax = None
        self.discriminator = None

        if product is not None:
            self.product = product
        if quantity is not None:
            self.quantity = quantity
        if price is not None:
            self.price = price
        if tax is not None:
            self.tax = tax

    @property
    def product(self):
        """Gets the product of this OrderProduct.  # noqa: E501


        :return: The product of this OrderProduct.  # noqa: E501
        :rtype: Product
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this OrderProduct.


        :param product: The product of this OrderProduct.  # noqa: E501
        :type: Product
        """

        self._product = product

    @property
    def quantity(self):
        """Gets the quantity of this OrderProduct.  # noqa: E501


        :return: The quantity of this OrderProduct.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this OrderProduct.


        :param quantity: The quantity of this OrderProduct.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def price(self):
        """Gets the price of this OrderProduct.  # noqa: E501

        It's unit price of current product, but not the total price. And it's the sell price exactly, not original or pre-tax.  # noqa: E501

        :return: The price of this OrderProduct.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this OrderProduct.

        It's unit price of current product, but not the total price. And it's the sell price exactly, not original or pre-tax.  # noqa: E501

        :param price: The price of this OrderProduct.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def tax(self):
        """Gets the tax of this OrderProduct.  # noqa: E501

        The tax of current product.  # noqa: E501

        :return: The tax of this OrderProduct.  # noqa: E501
        :rtype: float
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this OrderProduct.

        The tax of current product.  # noqa: E501

        :param tax: The tax of this OrderProduct.  # noqa: E501
        :type: float
        """

        self._tax = tax

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderProduct):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from nomad_connectors_cli.api.customs_callback_api import CustomsCallbackApi
from nomad_connectors_cli.api.customs_order_api import CustomsOrderApi
from nomad_connectors_cli.api.customs_payment_api import CustomsPaymentApi
from nomad_connectors_cli.api.customs_product_api import CustomsProductApi
from nomad_connectors_cli.api.order_api import OrderApi
from nomad_connectors_cli.api.product_api import ProductApi
from nomad_connectors_cli.api.ship_api import ShipApi



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Images(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ids': 'list[str]',
        'urls': 'list[str]',
        'uploads': 'list[str]'
    }

    attribute_map = {
        'ids': 'ids',
        'urls': 'urls',
        'uploads': 'uploads'
    }

    def __init__(self, ids=None, urls=None, uploads=None):  # noqa: E501
        """Images - a model defined in OpenAPI"""  # noqa: E501

        self._ids = None
        self._urls = None
        self._uploads = None
        self.discriminator = None

        if ids is not None:
            self.ids = ids
        if urls is not None:
            self.urls = urls
        if uploads is not None:
            self.uploads = uploads

    @property
    def ids(self):
        """Gets the ids of this Images.  # noqa: E501

        [response] The image ids of that platform.  # noqa: E501

        :return: The ids of this Images.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this Images.

        [response] The image ids of that platform.  # noqa: E501

        :param ids: The ids of this Images.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    @property
    def urls(self):
        """Gets the urls of this Images.  # noqa: E501

        [response] The image urls of that platform.  # noqa: E501

        :return: The urls of this Images.  # noqa: E501
        :rtype: list[str]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this Images.

        [response] The image urls of that platform.  # noqa: E501

        :param urls: The urls of this Images.  # noqa: E501
        :type: list[str]
        """

        self._urls = urls

    @property
    def uploads(self):
        """Gets the uploads of this Images.  # noqa: E501

        [request] Upload one or more images to a specific platform via URL  # noqa: E501

        :return: The uploads of this Images.  # noqa: E501
        :rtype: list[str]
        """
        return self._uploads

    @uploads.setter
    def uploads(self, uploads):
        """Sets the uploads of this Images.

        [request] Upload one or more images to a specific platform via URL  # noqa: E501

        :param uploads: The uploads of this Images.  # noqa: E501
        :type: list[str]
        """

        self._uploads = uploads

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Images):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_connectors_cli
from nomad_connectors_cli.models.order_product import OrderProduct  # noqa: E501
from nomad_connectors_cli.rest import ApiException


class TestOrderProduct(unittest.TestCase):
    """OrderProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrderProduct(self):
        """Test OrderProduct"""
        # FIXME: construct object with mandatory attributes with example values
        # model = nomad_connectors_cli.models.order_product.OrderProduct()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "nomad_connectors_cli"
VERSION = "0.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Nomad Envoy/Pilot",
    author_email="paul@samarkand.global",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Nomad Envoy/Pilot"],
    install_requires=REQUIRES + ["querystring==0.1.0"],
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501
    """
)



# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Order(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'order_id': 'str',
        'client_order_ref': 'str',
        'client_parent_order_ref': 'str',
        'platform_transaction_id': 'str',
        'is_sub_order': 'bool',
        'is_distribution_order': 'bool',
        'order_type': 'str',
        'items': 'list[OrderProduct]',
        'customer': 'Address',
        'customer_id_ref': 'str',
        'seller': 'Address',
        'payer': 'Address',
        'status': 'str',
        'tracking_reference': 'str',
        'destination_code': 'str',
        'node_code': 'str',
        'express_company': 'str',
        'express_type': 'str',
        'currency': 'str',
        'customs_code': 'str',
        'customs_filing_id': 'str',
        'created_at': 'str',
        'updated_at': 'str',
        'pay_method': 'str',
        'pay_merchant_name': 'str',
        'pay_amount': 'float',
        'pay_id': 'str',
        'payment_pay_id': 'str',
        'paid_at': 'str',
        'pay_customs_no': 'str',
        'products_total_tax': 'float',
        'shipping_cost': 'float',
        'non_cash_deduction_amount': 'float',
        'insurance_fee': 'float',
        'customer_note': 'str'
    }

    attribute_map = {
        'order_id': 'orderId',
        'client_order_ref': 'clientOrderRef',
        'client_parent_order_ref': 'clientParentOrderRef',
        'platform_transaction_id': 'platformTransactionId',
        'is_sub_order': 'isSubOrder',
        'is_distribution_order': 'isDistributionOrder',
        'order_type': 'orderType',
        'items': 'items',
        'customer': 'customer',
        'customer_id_ref': 'customerIdRef',
        'seller': 'seller',
        'payer': 'payer',
        'status': 'status',
        'tracking_reference': 'trackingReference',
        'destination_code': 'destinationCode',
        'node_code': 'nodeCode',
        'express_company': 'expressCompany',
        'express_type': 'expressType',
        'currency': 'currency',
        'customs_code': 'customsCode',
        'customs_filing_id': 'customsFilingId',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'pay_method': 'payMethod',
        'pay_merchant_name': 'payMerchantName',
        'pay_amount': 'payAmount',
        'pay_id': 'payId',
        'payment_pay_id': 'paymentPayId',
        'paid_at': 'paidAt',
        'pay_customs_no': 'payCustomsNo',
        'products_total_tax': 'productsTotalTax',
        'shipping_cost': 'shippingCost',
        'non_cash_deduction_amount': 'nonCashDeductionAmount',
        'insurance_fee': 'insuranceFee',
        'customer_note': 'customerNote'
    }

    def __init__(self, order_id=None, client_order_ref=None, client_parent_order_ref=None, platform_transaction_id=None, is_sub_order=False, is_distribution_order=False, order_type='DEFAULT', items=None, customer=None, customer_id_ref=None, seller=None, payer=None, status=None, tracking_reference=None, destination_code=None, node_code=None, express_company=None, express_type=None, currency='RMB', customs_code='SH', customs_filing_id=None, created_at=None, updated_at=None, pay_method=None, pay_merchant_name=None, pay_amount=None, pay_id=None, payment_pay_id=None, paid_at=None, pay_customs_no=None, products_total_tax=None, shipping_cost=None, non_cash_deduction_amount=None, insurance_fee=None, customer_note=None):  # noqa: E501
        """Order - a model defined in OpenAPI"""  # noqa: E501

        self._order_id = None
        self._client_order_ref = None
        self._client_parent_order_ref = None
        self._platform_transaction_id = None
        self._is_sub_order = None
        self._is_distribution_order = None
        self._order_type = None
        self._items = None
        self._customer = None
        self._customer_id_ref = None
        self._seller = None
        self._payer = None
        self._status = None
        self._tracking_reference = None
        self._destination_code = None
        self._node_code = None
        self._express_company = None
        self._express_type = None
        self._currency = None
        self._customs_code = None
        self._customs_filing_id = None
        self._created_at = None
        self._updated_at = None
        self._pay_method = None
        self._pay_merchant_name = None
        self._pay_amount = None
        self._pay_id = None
        self._payment_pay_id = None
        self._paid_at = None
        self._pay_customs_no = None
        self._products_total_tax = None
        self._shipping_cost = None
        self._non_cash_deduction_amount = None
        self._insurance_fee = None
        self._customer_note = None
        self.discriminator = None

        if order_id is not None:
            self.order_id = order_id
        if client_order_ref is not None:
            self.client_order_ref = client_order_ref
        if client_parent_order_ref is not None:
            self.client_parent_order_ref = client_parent_order_ref
        if platform_transaction_id is not None:
            self.platform_transaction_id = platform_transaction_id
        if is_sub_order is not None:
            self.is_sub_order = is_sub_order
        if is_distribution_order is not None:
            self.is_distribution_order = is_distribution_order
        if order_type is not None:
            self.order_type = order_type
        if items is not None:
            self.items = items
        if customer is not None:
            self.customer = customer
        if customer_id_ref is not None:
            self.customer_id_ref = customer_id_ref
        if seller is not None:
            self.seller = seller
        if payer is not None:
            self.payer = payer
        if status is not None:
            self.status = status
        if tracking_reference is not None:
            self.tracking_reference = tracking_reference
        if destination_code is not None:
            self.destination_code = destination_code
        if node_code is not None:
            self.node_code = node_code
        if express_company is not None:
            self.express_company = express_company
        if express_type is not None:
            self.express_type = express_type
        self.currency = currency
        if customs_code is not None:
            self.customs_code = customs_code
        if customs_filing_id is not None:
            self.customs_filing_id = customs_filing_id
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if pay_method is not None:
            self.pay_method = pay_method
        if pay_merchant_name is not None:
            self.pay_merchant_name = pay_merchant_name
        if pay_amount is not None:
            self.pay_amount = pay_amount
        if pay_id is not None:
            self.pay_id = pay_id
        if payment_pay_id is not None:
            self.payment_pay_id = payment_pay_id
        if paid_at is not None:
            self.paid_at = paid_at
        if pay_customs_no is not None:
            self.pay_customs_no = pay_customs_no
        if products_total_tax is not None:
            self.products_total_tax = products_total_tax
        if shipping_cost is not None:
            self.shipping_cost = shipping_cost
        if non_cash_deduction_amount is not None:
            self.non_cash_deduction_amount = non_cash_deduction_amount
        if insurance_fee is not None:
            self.insurance_fee = insurance_fee
        if customer_note is not None:
            self.customer_note = customer_note

    @property
    def order_id(self):
        """Gets the order_id of this Order.  # noqa: E501

        Order ID ref (Odoo platform).  # noqa: E501

        :return: The order_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this Order.

        Order ID ref (Odoo platform).  # noqa: E501

        :param order_id: The order_id of this Order.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def client_order_ref(self):
        """Gets the client_order_ref of this Order.  # noqa: E501

        Client order ref (third party platform)  # noqa: E501

        :return: The client_order_ref of this Order.  # noqa: E501
        :rtype: str
        """
        return self._client_order_ref

    @client_order_ref.setter
    def client_order_ref(self, client_order_ref):
        """Sets the client_order_ref of this Order.

        Client order ref (third party platform)  # noqa: E501

        :param client_order_ref: The client_order_ref of this Order.  # noqa: E501
        :type: str
        """

        self._client_order_ref = client_order_ref

    @property
    def client_parent_order_ref(self):
        """Gets the client_parent_order_ref of this Order.  # noqa: E501

        Client parent order ref (third party platform)  # noqa: E501

        :return: The client_parent_order_ref of this Order.  # noqa: E501
        :rtype: str
        """
        return self._client_parent_order_ref

    @client_parent_order_ref.setter
    def client_parent_order_ref(self, client_parent_order_ref):
        """Sets the client_parent_order_ref of this Order.

        Client parent order ref (third party platform)  # noqa: E501

        :param client_parent_order_ref: The client_parent_order_ref of this Order.  # noqa: E501
        :type: str
        """

        self._client_parent_order_ref = client_parent_order_ref

    @property
    def platform_transaction_id(self):
        """Gets the platform_transaction_id of this Order.  # noqa: E501

        Client transaction id (third party platform), e.g. PDD for customs purpose payment  # noqa: E501

        :return: The platform_transaction_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._platform_transaction_id

    @platform_transaction_id.setter
    def platform_transaction_id(self, platform_transaction_id):
        """Sets the platform_transaction_id of this Order.

        Client transaction id (third party platform), e.g. PDD for customs purpose payment  # noqa: E501

        :param platform_transaction_id: The platform_transaction_id of this Order.  # noqa: E501
        :type: str
        """

        self._platform_transaction_id = platform_transaction_id

    @property
    def is_sub_order(self):
        """Gets the is_sub_order of this Order.  # noqa: E501

        declare if current order is a sub order.  # noqa: E501

        :return: The is_sub_order of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_sub_order

    @is_sub_order.setter
    def is_sub_order(self, is_sub_order):
        """Sets the is_sub_order of this Order.

        declare if current order is a sub order.  # noqa: E501

        :param is_sub_order: The is_sub_order of this Order.  # noqa: E501
        :type: bool
        """

        self._is_sub_order = is_sub_order

    @property
    def is_distribution_order(self):
        """Gets the is_distribution_order of this Order.  # noqa: E501

        declare if current order is a distribution order.  # noqa: E501

        :return: The is_distribution_order of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._is_distribution_order

    @is_distribution_order.setter
    def is_distribution_order(self, is_distribution_order):
        """Sets the is_distribution_order of this Order.

        declare if current order is a distribution order.  # noqa: E501

        :param is_distribution_order: The is_distribution_order of this Order.  # noqa: E501
        :type: bool
        """

        self._is_distribution_order = is_distribution_order

    @property
    def order_type(self):
        """Gets the order_type of this Order.  # noqa: E501

        Current order type, could be one of DEFAULT/DISTRIBUTOR/SUPPLIER  # noqa: E501

        :return: The order_type of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_type

    @order_type.setter
    def order_type(self, order_type):
        """Sets the order_type of this Order.

        Current order type, could be one of DEFAULT/DISTRIBUTOR/SUPPLIER  # noqa: E501

        :param order_type: The order_type of this Order.  # noqa: E501
        :type: str
        """

        self._order_type = order_type

    @property
    def items(self):
        """Gets the items of this Order.  # noqa: E501

        Products in order.  # noqa: E501

        :return: The items of this Order.  # noqa: E501
        :rtype: list[OrderProduct]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Order.

        Products in order.  # noqa: E501

        :param items: The items of this Order.  # noqa: E501
        :type: list[OrderProduct]
        """

        self._items = items

    @property
    def customer(self):
        """Gets the customer of this Order.  # noqa: E501


        :return: The customer of this Order.  # noqa: E501
        :rtype: Address
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this Order.


        :param customer: The customer of this Order.  # noqa: E501
        :type: Address
        """

        self._customer = customer

    @property
    def customer_id_ref(self):
        """Gets the customer_id_ref of this Order.  # noqa: E501

        The ID of buyer on current third party platform.  # noqa: E501

        :return: The customer_id_ref of this Order.  # noqa: E501
        :rtype: str
        """
        return self._customer_id_ref

    @customer_id_ref.setter
    def customer_id_ref(self, customer_id_ref):
        """Sets the customer_id_ref of this Order.

        The ID of buyer on current third party platform.  # noqa: E501

        :param customer_id_ref: The customer_id_ref of this Order.  # noqa: E501
        :type: str
        """

        self._customer_id_ref = customer_id_ref

    @property
    def seller(self):
        """Gets the seller of this Order.  # noqa: E501


        :return: The seller of this Order.  # noqa: E501
        :rtype: Address
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this Order.


        :param seller: The seller of this Order.  # noqa: E501
        :type: Address
        """

        self._seller = seller

    @property
    def payer(self):
        """Gets the payer of this Order.  # noqa: E501


        :return: The payer of this Order.  # noqa: E501
        :rtype: Address
        """
        return self._payer

    @payer.setter
    def payer(self, payer):
        """Sets the payer of this Order.


        :param payer: The payer of this Order.  # noqa: E501
        :type: Address
        """

        self._payer = payer

    @property
    def status(self):
        """Gets the status of this Order.  # noqa: E501

        View valid status at get /order query params  # noqa: E501

        :return: The status of this Order.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Order.

        View valid status at get /order query params  # noqa: E501

        :param status: The status of this Order.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def tracking_reference(self):
        """Gets the tracking_reference of this Order.  # noqa: E501

        package tracking reference.  # noqa: E501

        :return: The tracking_reference of this Order.  # noqa: E501
        :rtype: str
        """
        return self._tracking_reference

    @tracking_reference.setter
    def tracking_reference(self, tracking_reference):
        """Sets the tracking_reference of this Order.

        package tracking reference.  # noqa: E501

        :param tracking_reference: The tracking_reference of this Order.  # noqa: E501
        :type: str
        """

        self._tracking_reference = tracking_reference

    @property
    def destination_code(self):
        """Gets the destination_code of this Order.  # noqa: E501

        Proposed by Onion, original Chinese phrase is 三段码.  # noqa: E501

        :return: The destination_code of this Order.  # noqa: E501
        :rtype: str
        """
        return self._destination_code

    @destination_code.setter
    def destination_code(self, destination_code):
        """Sets the destination_code of this Order.

        Proposed by Onion, original Chinese phrase is 三段码.  # noqa: E501

        :param destination_code: The destination_code of this Order.  # noqa: E501
        :type: str
        """

        self._destination_code = destination_code

    @property
    def node_code(self):
        """Gets the node_code of this Order.  # noqa: E501

        Proposed by Onion, original Chinese phrase is 集包地.  # noqa: E501

        :return: The node_code of this Order.  # noqa: E501
        :rtype: str
        """
        return self._node_code

    @node_code.setter
    def node_code(self, node_code):
        """Sets the node_code of this Order.

        Proposed by Onion, original Chinese phrase is 集包地.  # noqa: E501

        :param node_code: The node_code of this Order.  # noqa: E501
        :type: str
        """

        self._node_code = node_code

    @property
    def express_company(self):
        """Gets the express_company of this Order.  # noqa: E501

        Logistic companies, e.g. STO, Goldjet.  # noqa: E501

        :return: The express_company of this Order.  # noqa: E501
        :rtype: str
        """
        return self._express_company

    @express_company.setter
    def express_company(self, express_company):
        """Sets the express_company of this Order.

        Logistic companies, e.g. STO, Goldjet.  # noqa: E501

        :param express_company: The express_company of this Order.  # noqa: E501
        :type: str
        """

        self._express_company = express_company

    @property
    def express_type(self):
        """Gets the express_type of this Order.  # noqa: E501

        BC/BBC.  BC means business-customer, BBC means business-business-customer, like distribution sell mode.  # noqa: E501

        :return: The express_type of this Order.  # noqa: E501
        :rtype: str
        """
        return self._express_type

    @express_type.setter
    def express_type(self, express_type):
        """Sets the express_type of this Order.

        BC/BBC.  BC means business-customer, BBC means business-business-customer, like distribution sell mode.  # noqa: E501

        :param express_type: The express_type of this Order.  # noqa: E501
        :type: str
        """

        self._express_type = express_type

    @property
    def currency(self):
        """Gets the currency of this Order.  # noqa: E501

        The currency used in current order, it makes sense if we declare it explicitly.  # noqa: E501

        :return: The currency of this Order.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Order.

        The currency used in current order, it makes sense if we declare it explicitly.  # noqa: E501

        :param currency: The currency of this Order.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def customs_code(self):
        """Gets the customs_code of this Order.  # noqa: E501

        海关编号 ZZ:郑州新郑综合保税区；GZ：广州海关；HZ：杭州海关；SH：上海海关  # noqa: E501

        :return: The customs_code of this Order.  # noqa: E501
        :rtype: str
        """
        return self._customs_code

    @customs_code.setter
    def customs_code(self, customs_code):
        """Sets the customs_code of this Order.

        海关编号 ZZ:郑州新郑综合保税区；GZ：广州海关；HZ：杭州海关；SH：上海海关  # noqa: E501

        :param customs_code: The customs_code of this Order.  # noqa: E501
        :type: str
        """

        self._customs_code = customs_code

    @property
    def customs_filing_id(self):
        """Gets the customs_filing_id of this Order.  # noqa: E501

        The filing id that returned from Customs  # noqa: E501

        :return: The customs_filing_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._customs_filing_id

    @customs_filing_id.setter
    def customs_filing_id(self, customs_filing_id):
        """Sets the customs_filing_id of this Order.

        The filing id that returned from Customs  # noqa: E501

        :param customs_filing_id: The customs_filing_id of this Order.  # noqa: E501
        :type: str
        """

        self._customs_filing_id = customs_filing_id

    @property
    def created_at(self):
        """Gets the created_at of this Order.  # noqa: E501

        The time when current order was created. ISO_8601 format  # noqa: E501

        :return: The created_at of this Order.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Order.

        The time when current order was created. ISO_8601 format  # noqa: E501

        :param created_at: The created_at of this Order.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Order.  # noqa: E501

        The time when current order was updated. ISO_8601 format  # noqa: E501

        :return: The updated_at of this Order.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Order.

        The time when current order was updated. ISO_8601 format  # noqa: E501

        :param updated_at: The updated_at of this Order.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def pay_method(self):
        """Gets the pay_method of this Order.  # noqa: E501


        :return: The pay_method of this Order.  # noqa: E501
        :rtype: str
        """
        return self._pay_method

    @pay_method.setter
    def pay_method(self, pay_method):
        """Sets the pay_method of this Order.


        :param pay_method: The pay_method of this Order.  # noqa: E501
        :type: str
        """

        self._pay_method = pay_method

    @property
    def pay_merchant_name(self):
        """Gets the pay_merchant_name of this Order.  # noqa: E501


        :return: The pay_merchant_name of this Order.  # noqa: E501
        :rtype: str
        """
        return self._pay_merchant_name

    @pay_merchant_name.setter
    def pay_merchant_name(self, pay_merchant_name):
        """Sets the pay_merchant_name of this Order.


        :param pay_merchant_name: The pay_merchant_name of this Order.  # noqa: E501
        :type: str
        """

        self._pay_merchant_name = pay_merchant_name

    @property
    def pay_amount(self):
        """Gets the pay_amount of this Order.  # noqa: E501

        The amount of final paid.  # noqa: E501

        :return: The pay_amount of this Order.  # noqa: E501
        :rtype: float
        """
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, pay_amount):
        """Sets the pay_amount of this Order.

        The amount of final paid.  # noqa: E501

        :param pay_amount: The pay_amount of this Order.  # noqa: E501
        :type: float
        """

        self._pay_amount = pay_amount

    @property
    def pay_id(self):
        """Gets the pay_id of this Order.  # noqa: E501

        The pay number generated by the eCommerce platform such as Youzan  # noqa: E501

        :return: The pay_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._pay_id

    @pay_id.setter
    def pay_id(self, pay_id):
        """Sets the pay_id of this Order.

        The pay number generated by the eCommerce platform such as Youzan  # noqa: E501

        :param pay_id: The pay_id of this Order.  # noqa: E501
        :type: str
        """

        self._pay_id = pay_id

    @property
    def payment_pay_id(self):
        """Gets the payment_pay_id of this Order.  # noqa: E501

        the payment number generated by payment tool such as WeChat Pay  # noqa: E501

        :return: The payment_pay_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._payment_pay_id

    @payment_pay_id.setter
    def payment_pay_id(self, payment_pay_id):
        """Sets the payment_pay_id of this Order.

        the payment number generated by payment tool such as WeChat Pay  # noqa: E501

        :param payment_pay_id: The payment_pay_id of this Order.  # noqa: E501
        :type: str
        """

        self._payment_pay_id = payment_pay_id

    @property
    def paid_at(self):
        """Gets the paid_at of this Order.  # noqa: E501

        The time when the pay was made. ISO_8601 format  # noqa: E501

        :return: The paid_at of this Order.  # noqa: E501
        :rtype: str
        """
        return self._paid_at

    @paid_at.setter
    def paid_at(self, paid_at):
        """Sets the paid_at of this Order.

        The time when the pay was made. ISO_8601 format  # noqa: E501

        :param paid_at: The paid_at of this Order.  # noqa: E501
        :type: str
        """

        self._paid_at = paid_at

    @property
    def pay_customs_no(self):
        """Gets the pay_customs_no of this Order.  # noqa: E501

        The payment declaration number from customs.  # noqa: E501

        :return: The pay_customs_no of this Order.  # noqa: E501
        :rtype: str
        """
        return self._pay_customs_no

    @pay_customs_no.setter
    def pay_customs_no(self, pay_customs_no):
        """Sets the pay_customs_no of this Order.

        The payment declaration number from customs.  # noqa: E501

        :param pay_customs_no: The pay_customs_no of this Order.  # noqa: E501
        :type: str
        """

        self._pay_customs_no = pay_customs_no

    @property
    def products_total_tax(self):
        """Gets the products_total_tax of this Order.  # noqa: E501

        The sum tax of all products in current order, including Non-cash deduction amount.  # noqa: E501

        :return: The products_total_tax of this Order.  # noqa: E501
        :rtype: float
        """
        return self._products_total_tax

    @products_total_tax.setter
    def products_total_tax(self, products_total_tax):
        """Sets the products_total_tax of this Order.

        The sum tax of all products in current order, including Non-cash deduction amount.  # noqa: E501

        :param products_total_tax: The products_total_tax of this Order.  # noqa: E501
        :type: float
        """

        self._products_total_tax = products_total_tax

    @property
    def shipping_cost(self):
        """Gets the shipping_cost of this Order.  # noqa: E501

        The shipping cost of current order, excluding the shipping cost on each contained products. If delivery free, just set 0.  # noqa: E501

        :return: The shipping_cost of this Order.  # noqa: E501
        :rtype: float
        """
        return self._shipping_cost

    @shipping_cost.setter
    def shipping_cost(self, shipping_cost):
        """Sets the shipping_cost of this Order.

        The shipping cost of current order, excluding the shipping cost on each contained products. If delivery free, just set 0.  # noqa: E501

        :param shipping_cost: The shipping_cost of this Order.  # noqa: E501
        :type: float
        """

        self._shipping_cost = shipping_cost

    @property
    def non_cash_deduction_amount(self):
        """Gets the non_cash_deduction_amount of this Order.  # noqa: E501

        Amount that deducted by non-cash, e.g. member points, virtual currency, voucher code, etc.  # noqa: E501

        :return: The non_cash_deduction_amount of this Order.  # noqa: E501
        :rtype: float
        """
        return self._non_cash_deduction_amount

    @non_cash_deduction_amount.setter
    def non_cash_deduction_amount(self, non_cash_deduction_amount):
        """Sets the non_cash_deduction_amount of this Order.

        Amount that deducted by non-cash, e.g. member points, virtual currency, voucher code, etc.  # noqa: E501

        :param non_cash_deduction_amount: The non_cash_deduction_amount of this Order.  # noqa: E501
        :type: float
        """

        self._non_cash_deduction_amount = non_cash_deduction_amount

    @property
    def insurance_fee(self):
        """Gets the insurance_fee of this Order.  # noqa: E501

        The insurance fee of current shipping.  # noqa: E501

        :return: The insurance_fee of this Order.  # noqa: E501
        :rtype: float
        """
        return self._insurance_fee

    @insurance_fee.setter
    def insurance_fee(self, insurance_fee):
        """Sets the insurance_fee of this Order.

        The insurance fee of current shipping.  # noqa: E501

        :param insurance_fee: The insurance_fee of this Order.  # noqa: E501
        :type: float
        """

        self._insurance_fee = insurance_fee

    @property
    def customer_note(self):
        """Gets the customer_note of this Order.  # noqa: E501

        The special note from the buyer.  # noqa: E501

        :return: The customer_note of this Order.  # noqa: E501
        :rtype: str
        """
        return self._customer_note

    @customer_note.setter
    def customer_note(self, customer_note):
        """Sets the customer_note of this Order.

        The special note from the buyer.  # noqa: E501

        :param customer_note: The customer_note of this Order.  # noqa: E501
        :type: str
        """

        self._customer_note = customer_note

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
